# Contibuting

If you would like to contribute, feel free to report issues, start new discussions, or create pull requests.

In general we recommend using our pre-commit hook which enforce the linter rules we use:

```shell
python3 -m pip install -U pre-commit
pre-commit install
```

In addition, please note we prefer using `'` for strings instead of `"`.

If you're having any troubles, You can also contact us on Discord:

<https://discord.gg/52mZGC3JXJ>

If you are lacking knowledge in how the different communication protocols work together, or how the project is
structured in design-form, you are advised to read:

[Understanding iDevice protocol layers](misc/understanding_idevice_protocol_layers.md)
